# biliscribe
A MCP Server that extracts and formats Bilibili video content into structured text, optimized for LLM processing and analysis.

I have only completed testing on macOS. Before running this MCP Server, you need to ensure that BBDown, ffmpeg, and whisperx can be called from zsh.